% figure 1
% Evolution of income inequality, wealth inequality, and uncertainty

clc;
clear;

mkt_income = readtable('average_factor_income_061723_WA.xlsx','Sheet',1,'Range','A2:I553');
mkt_income = table2array(mkt_income);
mkt_income = mkt_income(:,6:8);
mkt = mkt_income(:,1)./mkt_income(:,3);

dis_income = readtable('average_disposable_income_061723_WA.xlsx','Sheet',1,'Range','A2:I553');
dis_income = table2array(dis_income);
dis_income = dis_income(:,6:8);
dispo = dis_income(:,1)./dis_income(:,3);

labor_income = readtable('average_labor_income_061723_WA.xlsx','Sheet',1,'Range','A2:E553');
labor_income = table2array(labor_income);
labor_income = labor_income(:,3:5);
labor = labor_income(:,1)./labor_income(:,3);

nlabor_income = readtable('average_non_labor_income_WA_061723.xlsx','Sheet',1,'Range','A2:E553');
nlabor_income = table2array(nlabor_income);
nlabor_income = nlabor_income(:,3:5);
nlabor = nlabor_income(:,1)./nlabor_income(:,3);

wealth_data = readtable('wealth_share_061723_WA','Range','A2:H553');
wealth_data = table2array(wealth_data);
wealth = wealth_data(:,6);

uncertainty_data = readtable('fig1_uncertainty.xlsx','Range','C:F');
uncertainty_data = table2array(uncertainty_data);

vix = uncertainty_data(:,4);
financial = uncertainty_data(:,2);
macroeconomic = uncertainty_data(:,3);
epu = uncertainty_data(:,1);

vix_n = normalize(vix);
financial_n = normalize(financial);
macroeconomic_n = normalize(macroeconomic);
epu_n = normalize(epu);

recession_monthly = readtable('fig1_NBER_recession_monthly.xls','Range','12:575');
daytime_monthly = readtable('fig1_Monthly_date.xlsx');

income_ineq = [mkt, dispo, labor, nlabor];
unc_group = [vix_n, financial_n, macroeconomic_n, epu_n];

recess_mth = recession_monthly(:,2);
recess_mth = table2array(recess_mth);
recess_mth = recess_mth.*(max(max(income_ineq)));
recess_mth_bot = recess_mth.*(min(min(income_ineq)));

recess_mth_wealth = recess_mth.*(max(max(wealth)));
recess_mth_bot_wealth = recess_mth.*(min(min(wealth)));

recess_mth_unc = recess_mth.*(max(max(unc_group)));
recess_mth_bot_unc = recess_mth.*(min(min(unc_group)));

%% Baseline income inequality
subplot(1,3,1)
area(recess_mth, 'EdgeColor','none','FaceColor','#EAEAEA')
hold on;
fig1_1 = area(recess_mth_bot, 'EdgeColor','none','FaceColor','#EAEAEA');
hold on;
fig1_1.ShowBaseLine = 'off';
plot(mkt,'LineWidth',0.7)
hold on;
plot(labor,'LineWidth',0.7)
hold on;
plot(nlabor,'LineWidth',0.7)
hold on;
plot(dispo,'LineWidth',0.7)
hold on;
yline(0)
xlim([0 length(income_ineq)]);
ylim([min(min(income_ineq)) max(max(income_ineq))])
grid on;
ax = gca;
ax.GridColor = '#A6A6A6';
yr_monthly = 49:12*10:length(income_ineq);
xticks([yr_monthly]);
xticklabels({'1980','1990','2000','2010','2020'})
legend('','','market income', 'labor income', 'non-labor income','disposable income',...
    'Location','southoutside','Orientation','horizontal','NumColumns',2);
ylabel('Income inequality');
title('Baseline income inequality')
hold off;

%% Baseline wealth inequality
subplot(1,3,2)
area(recess_mth_wealth, 'EdgeColor','none','FaceColor','#EAEAEA')
hold on;
fig1_1 = area(recess_mth_bot_wealth, 'EdgeColor','none','FaceColor','#EAEAEA');
hold on;
fig1_2.ShowBaseLine = 'off';
plot(wealth,'LineWidth',0.7,'Color','k')
hold on;
yline(0)
xlim([0 length(wealth)]);
ylim([min(min(wealth)) max(max(wealth))])
grid on;
ax = gca;
ax.GridColor = '#A6A6A6';
yr_monthly = 49:12*10:length(wealth);
xticks([yr_monthly]);
xticklabels({'1980','1990','2000','2010','2020'})
legend('','','wealth',...
'Location','southoutside','Orientation','horizontal','NumColumns',2)
ylabel('Wealth share of top 10%');
title('Baseline wealth inequality')
hold off;

%% Uncertainty
subplot(1,3,3)
area(recess_mth_unc, 'EdgeColor','none','FaceColor','#EAEAEA')
hold on;
fig3_2 = area(recess_mth_bot_unc, 'EdgeColor','none','FaceColor','#EAEAEA');
hold on;
fig3_2.ShowBaseLine = 'off';
%'LineStyle','--'
plot(financial_n,'LineWidth',0.3)
hold on;
plot(macroeconomic_n,'LineWidth',0.3)
hold on;
plot(vix_n,'LineWidth',0.3)
hold on;
plot(epu_n,'LineWidth',0.3)
hold on;
yline(0,'Color','#747474')
xlim([0 length(uncertainty_data)]);
ylim([min(min([vix_n, financial_n,macroeconomic_n, epu_n]))...
    max(max([vix_n, financial_n,macroeconomic_n, epu_n]))])
grid on;
ax = gca;
ax.GridColor = '#A6A6A6';
yr_monthly = 49:12*10:length(uncertainty_data);
xticks([yr_monthly]);
xticklabels({'1980','1990','2000','2010','2020'})
legend('','','JLN FU', 'JLN MU',...
    'VIX', 'EPU',...
    'Location','southoutside','Orientation','horizontal','NumColumns',2)
ylabel('Uncertainty');
title('Uncertainty measures')
hold off;